# remirepo spec file for hdrhistogram
#
# Copyright (c) 2016-2019 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%global gh_commit   50f130578320e95f917d6a33d45faedc3500fe1f
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    HdrHistogram
%global gh_project  HdrHistogram_c
%global libname     libhdr_histogram
%global soname      3

Name:          hdrhistogram
Summary:       A High Dynamic Range (HDR) Histogram
Version:       0.9.11
Release:       1%{?dist}
License:       CC0 or BSD

URL:           https://github.com/%{gh_owner}/%{gh_project}
Source0:       https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}-%{gh_short}.tar.gz

# build with fPIC
Patch0:        %{name}-fpic.patch

BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: cmake > 2.8
BuildRequires: zlib-devel

Requires:   %{name}-libs%{?_isa} = %{version}-%{release}


%description
HdrHistogram: A High Dynamic Range (HDR) Histogram.

This port contains a subset of the functionality supported
by the Java implementation. The current supported features are:

- Standard histogram with 64 bit counts (32/16 bit counts not supported)
- All iterator types (all values, recorded, percentiles, linear, logarithmic)
- Histogram serialisation (encoding version 1.2, decoding 1.0-1.2)
- Reader/writer phaser and interval recorder


%package devel
Summary:    Header files and development libraries for %{name}
Requires:   %{name}%{?_isa} = %{version}-%{release}

%description devel
This package contains the header files and development libraries
for %{name}.


%package libs
Summary:    A High Dynamic Range (HDR) Histogram C library
Group:      System Environment/Libraries

%description libs
This package contains the %{libname} library.


%prep
%setup -q -n %{gh_project}-%{gh_commit}

mkdir docs
cp -pr examples docs/examples

%patch0 -p1 -b .fpic

grep CMAKE_C_FLAGS CMakeLists.txt


%build
export CFLAGS="%{optflags} -Wno-unknown-pragmas -std=gnu99"

%cmake .
make %{_smp_mflags}


%install
make install DESTDIR="%{buildroot}"

rm %{buildroot}/%{_libdir}/%{libname}_static.a
rm %{buildroot}/%{_bindir}/*test


%check
make test


%if 0%{?fedora} < 28 && 0%{?rhel} < 8
%post   libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig
%endif



%files
%doc *.md
%{_bindir}/hiccup
%{_bindir}/hdr_decoder

%files libs
%{!?_licensedir:%global license %%doc}
%license COPYING.txt
%license LICENSE.txt
%{_libdir}/%{libname}.so.%{soname}*

%files devel
%doc *.md
%doc docs/examples
%{_libdir}/%{libname}.so
%{_includedir}/hdr


%changelog
* Mon Jun 17 2019 Remi Collet <remi@remirepo.net> - 0.9.11-1
- update to 0.9.11

* Mon May 20 2019 Remi Collet <remi@remirepo.net> - 0.9.10-1
- update to 0.9.10

* Mon Jan 21 2019 Remi Collet <remi@remirepo.net> - 0.9.8-1
- update to 0.9.8
- soname bump to 3

* Wed Aug 22 2018 Remi Collet <remi@remirepo.net> - 0.9.7-3
- F29 cleanup

* Mon Feb 26 2018 Remi Collet <remi@remirepo.net> - 0.9.7-2
- F28 cleanup

* Fri Sep 15 2017 Remi Collet <remi@remirepo.net> - 0.9.7-1
- update to 0.9.7

* Tue Aug 22 2017 Remi Collet <remi@fedoraproject.org> - 0.9.6-2
- honour default RPM build options

* Fri Apr 21 2017 Remi Collet <remi@fedoraproject.org> - 0.9.6-1
- update to 0.9.6

* Sun Sep  4 2016 Remi Collet <remi@fedoraproject.org> - 0.9.5-1
- update to 0.9.5

* Mon Jul 18 2016 Remi Collet <remi@fedoraproject.org> - 0.9.4-1
- update to 0.9.4

* Wed Apr  6 2016 Remi Collet <remi@fedoraproject.org> - 0.9.3-1
- update to 0.9.3

* Fri Jan  1 2016 Remi Collet <remi@fedoraproject.org> - 0.9.1-1
- initial package
